<?php
/**
 * RepoQuery Web service
 * repoQuery.php
 * Returns the list of subscribers to an archive.
 * Must be stored in a directory at the same level as the Repository directory
 * that contains subscribers.rep.
 * Requires Pear SOAP.
 * Version 0.0.4
 * Copyright (c) 2001-2002 Alexis Grandemange
 * Mail: alexis.grandemange@pagebox.net
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; version
 * 2.1 of the License.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 * A copy of the GNU Lesser General Public License lesser.txt should be
 * included in the distribution.
 */
require_once 'SOAP/Server.php';
include("../repository/archive.inc");
$status = "Subscribers not set";
/**
 * Web service class
 */
class RepoQuery {
    var $method_namespace = 'urn:Repository';
    var $dispatch_map = array();
    var $status;
    var $rso;
    function RepoQuery($status, $rso) {
        $this->status = $status;
        $this->rso = $rso;
    }
    /**
     * Web service method.
     * Parameters:
     * archive: archive whose subscribers must be returned
     * deployURL: this deployment URL (to not include in the returned list
     * Returns a SOAP_Value aarray of subscribers.
     */
    function GetSubscribers($archive, $deployURL)
    {
        $arr = NULL;
        audit("RepoQuery.GetSubscribers(" . $archive . ")", "RepoQuery", $deployURL);
        if (($this->status != "Repository locked - retry later") &&
            ($this->rso->subscribers != NULL)) {
            $du = "http://" . $deployURL;
            while (list($key, $value) = each ($this->rso->subscribers)) {
                if ($key == $du)
                    continue;
                // audit("key: " . $key, "RepoQuery", $deployURL);
                if (key_exists($archive, $value->arch))
                    $arr[] = new SOAP_Value('item','string',$key);    
            }
            if ($arr != NULL)
	        return new SOAP_Value('outputArray', NULL , $arr);
	    else
	        $this->status = "No other subscriber";
        }
        $arr[] = new SOAP_Value('item','string',$this->status);
	return new SOAP_Value('outputArray', NULL , $arr);
    }    
}
if (!lock("repoQuery.php", "anonymous", "SOAP")) {
    $status = "Repository locked - retry later";
} else {
    /**
     * Request handling.
     * Queried in GET mode by itself.
     */
    $download = "";
    $requri = $HTTP_SERVER_VARS["REQUEST_URI"];
    $begin = substr($requri, 0, 7);
    if ($begin == "http://") {
        $requri = substr($requri, 7);
        $download = str_replace("repoQuery", "download", dirname($requri));
    } else {
        $download = $HTTP_SERVER_VARS["HTTP_HOST"] . str_replace("repository", "download", dirname($requri));
    }
    // echo $download . "<br/>";
    $RepoSubsObj = restore_subscribers($download);
}
$server = new SOAP_Server;
$soapclass = new RepoQuery($status, $RepoSubsObj);
$server->addObjectMap($soapclass);
$server->service($HTTP_RAW_POST_DATA);
?>